@@ -4,14 +4,15 @@ USER_AGENT = 'Mozilla/5.0 (Windows NT 10.0; Win64; x64; rv:95.0) Gecko/20100101
 ORIGIN = 'https://www.bilibili.com'
 REFERER = 'https://www.bilibili.com/'
 
-def getPage(url, dest, encoding):
+def getPage(url, dest, encoding='utf-8'):
     headers = {
         'User-Agent': USER_AGENT,
     }
-    response = requests.get(url=url, headers=headers).content.decode(encoding=encoding)
+    response = requests.get(url=url, headers=headers)
     print(response.status_code)
+    content = response.content.decode(encoding=encoding)
     fw = open(dest, 'w', encoding='utf-8')
-    fw.write(response)
+    fw.write(content)
     fw.close()
     return
 
@@ -33,4 +34,8 @@ def download(url, dest):
         print("url下载错误: %s" % url)
         print(e)
 
-    return
\ No newline at end of file
+    return
+
+if __name__ == '__main__':
+
+    pass
\ No newline at end of file
